# SPDX-FileCopyrightText: 2025 Qoro Quantum Ltd <divi@qoroquantum.de>
#
# SPDX-License-Identifier: Apache-2.0

from . import _qasm_export  # Does nothing, just initiates the patch
from ._parser import ExtendedQasmParser
